/***************************************************************************
    File                 : ImportDialog.h
    Project              : SciDAVis
    --------------------------------------------------------------------
    Copyright            : (C) 2008 Knut Franke
    Email (use @ for *)  : Knut.Franke*gmx.net
    Description          : Select file(s) to import and import filter to use.

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
 *   Boston, MA  02110-1301  USA                                           *
 *                                                                         *
 ***************************************************************************/

#ifndef IMPORT_DIALOG_H
#define IMPORT_DIALOG_H

#include "lib/ExtensibleFileDialog.h"
#include <QMap>

class AbstractImportFilter;
class QMetaProperty;
class QComboBox;

//! Select files to import and import filter to use.
/**
 * This class is intimately related with AbstractImportFilter; see its documentation for a detailed
 * description of import filters.
 */
class ImportDialog : public ExtensibleFileDialog
{
	Q_OBJECT

	public:
		//! Possible destinations for imported Aspects.
		// IMPORTANT: keep this in sync with initialization of m_destination
		enum Destination {
			CurrentProject,  //!< import into current project
			NewProjects,     //!< import as new projects or into newly created projects
			//TODO: how does importing ASCII tables as new columns or rows fit in?
			// maybe like so (add something like virtual bool AbstractPart::merge(AbstractPart* other)):
			// CurrentPart, //!< merge into current Part
		};
		//! Constructor.
		ImportDialog(QMap<QString, AbstractImportFilter*> filter_map, QWidget *parent=0);
		//! The selected destination for imported Aspects.
		Destination destination() const;

	public slots:
		//! Called when the user selects a different import filter.
		void filterChanged(const QString&);

	protected slots:
		//! Used to update integer properties of an auto-generated options ui.
		void intValueChanged(int);
		//! Used to update bool properties of an auto-generated options ui.
		void boolValueChanged(int);
		//! Used to update string properties of an auto-generated options ui.
		void stringValueChanged(const QString&);

	private:
		//! Auto-generate an options ui from properties of the input filter.
		QWidget * generateOptionsGUI();

		//! The currently selected import filter.
		AbstractImportFilter * m_filter;
		//! Maps the filter strings used by QFileDialog ("name and patterns") to import filters.
		QMap<QString, AbstractImportFilter*> m_filter_map;
		//! Maps input widgets (== sender() in *ValueChanged()) to corresponding properties of the import filter.
		QMap<QObject*, QMetaProperty*> m_settings_map;
		//! Combo box for selecting the destination of imported Aspects (see enum Destination).
		QComboBox * m_destination;
		//! GUI for filter options, either generated by the filter or by generateOptionsGUI().
		QWidget * m_options_ui;
};

#endif // ifndef IMPORT_DIALOG_H
